==> terra-proto-1.1.0b2.tar.gz: terra-proto-1.1.0b2/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['terra_proto',
 'terra_proto.cosmos',
 'terra_proto.cosmos.auth',
 'terra_proto.cosmos.auth.v1beta1',
 'terra_proto.cosmos.authz',
 'terra_proto.cosmos.authz.v1beta1',
 'terra_proto.cosmos.bank',
 'terra_proto.cosmos.bank.v1beta1',
 'terra_proto.cosmos.base',
 'terra_proto.cosmos.base.abci',
 'terra_proto.cosmos.base.abci.v1beta1',
 'terra_proto.cosmos.base.kv',
 'terra_proto.cosmos.base.kv.v1beta1',
 'terra_proto.cosmos.base.query',
 'terra_proto.cosmos.base.query.v1beta1',
 'terra_proto.cosmos.base.reflection',
 'terra_proto.cosmos.base.reflection.v1beta1',
 'terra_proto.cosmos.base.reflection.v2alpha1',
 'terra_proto.cosmos.base.snapshots',
 'terra_proto.cosmos.base.snapshots.v1beta1',
 'terra_proto.cosmos.base.store',
 'terra_proto.cosmos.base.store.v1beta1',
 'terra_proto.cosmos.base.tendermint',
 'terra_proto.cosmos.base.tendermint.v1beta1',
 'terra_proto.cosmos.base.v1beta1',
 'terra_proto.cosmos.capability',
 'terra_proto.cosmos.capability.v1beta1',
 'terra_proto.cosmos.crisis',
 'terra_proto.cosmos.crisis.v1beta1',
 'terra_proto.cosmos.crypto',
 'terra_proto.cosmos.crypto.ed25519',
 'terra_proto.cosmos.crypto.multisig',
 'terra_proto.cosmos.crypto.multisig.v1beta1',
 'terra_proto.cosmos.crypto.secp256k1',
 'terra_proto.cosmos.crypto.secp256r1',
 'terra_proto.cosmos.distribution',
 'terra_proto.cosmos.distribution.v1beta1',
 'terra_proto.cosmos.evidence',
 'terra_proto.cosmos.evidence.v1beta1',
 'terra_proto.cosmos.feegrant',
 'terra_proto.cosmos.feegrant.v1beta1',
 'terra_proto.cosmos.genutil',
 'terra_proto.cosmos.genutil.v1beta1',
 'terra_proto.cosmos.gov',
 'terra_proto.cosmos.gov.v1beta1',
 'terra_proto.cosmos.mint',
 'terra_proto.cosmos.mint.v1beta1',
 'terra_proto.cosmos.params',
 'terra_proto.cosmos.params.v1beta1',
 'terra_proto.cosmos.slashing',
 'terra_proto.cosmos.slashing.v1beta1',
 'terra_proto.cosmos.staking',
 'terra_proto.cosmos.staking.v1beta1',
 'terra_proto.cosmos.tx',
 'terra_proto.cosmos.tx.signing',
 'terra_proto.cosmos.tx.signing.v1beta1',
 'terra_proto.cosmos.tx.v1beta1',
 'terra_proto.cosmos.upgrade',
 'terra_proto.cosmos.upgrade.v1beta1',
 'terra_proto.cosmos.vesting',
 'terra_proto.cosmos.vesting.v1beta1',
 'terra_proto.cosmos_proto',
 'terra_proto.cosmwasm',
 'terra_proto.cosmwasm.wasm',
 'terra_proto.cosmwasm.wasm.v1',
 'terra_proto.gogoproto',
 'terra_proto.google',
 'terra_proto.google.api',
 'terra_proto.ibc',
 'terra_proto.ibc.applications',
 'terra_proto.ibc.applications.fee',
 'terra_proto.ibc.applications.fee.v1',
 'terra_proto.ibc.applications.interchain_accounts',
 'terra_proto.ibc.applications.interchain_accounts.controller',
 'terra_proto.ibc.applications.interchain_accounts.controller.v1',
 'terra_proto.ibc.applications.interchain_accounts.host',
 'terra_proto.ibc.applications.interchain_accounts.host.v1',
 'terra_proto.ibc.applications.interchain_accounts.v1',
 'terra_proto.ibc.applications.transfer',
 'terra_proto.ibc.applications.transfer.v1',
 'terra_proto.ibc.applications.transfer.v2',
 'terra_proto.ibc.core',
 'terra_proto.ibc.core.channel',
 'terra_proto.ibc.core.channel.v1',
 'terra_proto.ibc.core.client',
 'terra_proto.ibc.core.client.v1',
 'terra_proto.ibc.core.commitment',
 'terra_proto.ibc.core.commitment.v1',
 'terra_proto.ibc.core.connection',
 'terra_proto.ibc.core.connection.v1',
 'terra_proto.ibc.core.types',
 'terra_proto.ibc.core.types.v1',
 'terra_proto.ibc.lightclients',
 'terra_proto.ibc.lightclients.localhost',
 'terra_proto.ibc.lightclients.localhost.v1',
 'terra_proto.ibc.lightclients.solomachine',
 'terra_proto.ibc.lightclients.solomachine.v1',
 'terra_proto.ibc.lightclients.solomachine.v2',
 'terra_proto.ibc.lightclients.tendermint',
 'terra_proto.ibc.lightclients.tendermint.v1',
 'terra_proto.ics23',
 'terra_proto.tendermint',
 'terra_proto.tendermint.abci',
 'terra_proto.tendermint.crypto',
 'terra_proto.tendermint.libs',
 'terra_proto.tendermint.libs.bits',
 'terra_proto.tendermint.p2p',
 'terra_proto.tendermint.types',
 'terra_proto.tendermint.version']

package_data = \
{'': ['*']}

install_requires = \
['betterproto==2.0.0b4']

setup_kwargs = {
    'name': 'terra-proto',
    'version': '1.1.0b2',
    'description': 'The Python Protobuf implementation for Terra',
    'long_description': '# python implementation for terra.proto\n',
    'author': 'Terraform Labs, PTE.',
    'author_email': 'engineering@terra.money',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/terra-money/terra.proto',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)

==> terra-proto-2.0.1b0.tar.gz: terra-proto-2.0.1b0/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['terra_proto',
 'terra_proto.cosmos',
 'terra_proto.cosmos.auth',
 'terra_proto.cosmos.auth.v1beta1',
 'terra_proto.cosmos.authz',
 'terra_proto.cosmos.authz.v1beta1',
 'terra_proto.cosmos.bank',
 'terra_proto.cosmos.bank.v1beta1',
 'terra_proto.cosmos.base',
 'terra_proto.cosmos.base.abci',
 'terra_proto.cosmos.base.abci.v1beta1',
 'terra_proto.cosmos.base.kv',
 'terra_proto.cosmos.base.kv.v1beta1',
 'terra_proto.cosmos.base.query',
 'terra_proto.cosmos.base.query.v1beta1',
 'terra_proto.cosmos.base.reflection',
 'terra_proto.cosmos.base.reflection.v1beta1',
 'terra_proto.cosmos.base.reflection.v2alpha1',
 'terra_proto.cosmos.base.snapshots',
 'terra_proto.cosmos.base.snapshots.v1beta1',
 'terra_proto.cosmos.base.store',
 'terra_proto.cosmos.base.store.v1beta1',
 'terra_proto.cosmos.base.tendermint',
 'terra_proto.cosmos.base.tendermint.v1beta1',
 'terra_proto.cosmos.base.v1beta1',
 'terra_proto.cosmos.capability',
 'terra_proto.cosmos.capability.v1beta1',
 'terra_proto.cosmos.crisis',
 'terra_proto.cosmos.crisis.v1beta1',
 'terra_proto.cosmos.crypto',
 'terra_proto.cosmos.crypto.ed25519',
 'terra_proto.cosmos.crypto.multisig',
 'terra_proto.cosmos.crypto.multisig.v1beta1',
 'terra_proto.cosmos.crypto.secp256k1',
 'terra_proto.cosmos.crypto.secp256r1',
 'terra_proto.cosmos.distribution',
 'terra_proto.cosmos.distribution.v1beta1',
 'terra_proto.cosmos.evidence',
 'terra_proto.cosmos.evidence.v1beta1',
 'terra_proto.cosmos.feegrant',
 'terra_proto.cosmos.feegrant.v1beta1',
 'terra_proto.cosmos.genutil',
 'terra_proto.cosmos.genutil.v1beta1',
 'terra_proto.cosmos.gov',
 'terra_proto.cosmos.gov.v1beta1',
 'terra_proto.cosmos.mint',
 'terra_proto.cosmos.mint.v1beta1',
 'terra_proto.cosmos.params',
 'terra_proto.cosmos.params.v1beta1',
 'terra_proto.cosmos.slashing',
 'terra_proto.cosmos.slashing.v1beta1',
 'terra_proto.cosmos.staking',
 'terra_proto.cosmos.staking.v1beta1',
 'terra_proto.cosmos.tx',
 'terra_proto.cosmos.tx.signing',
 'terra_proto.cosmos.tx.signing.v1beta1',
 'terra_proto.cosmos.tx.v1beta1',
 'terra_proto.cosmos.upgrade',
 'terra_proto.cosmos.upgrade.v1beta1',
 'terra_proto.cosmos.vesting',
 'terra_proto.cosmos.vesting.v1beta1',
 'terra_proto.cosmos_proto',
 'terra_proto.cosmwasm',
 'terra_proto.cosmwasm.wasm',
 'terra_proto.cosmwasm.wasm.v1',
 'terra_proto.gogoproto',
 'terra_proto.google',
 'terra_proto.google.api',
 'terra_proto.ibc',
 'terra_proto.ibc.applications',
 'terra_proto.ibc.applications.fee',
 'terra_proto.ibc.applications.fee.v1',
 'terra_proto.ibc.applications.interchain_accounts',
 'terra_proto.ibc.applications.interchain_accounts.controller',
 'terra_proto.ibc.applications.interchain_accounts.controller.v1',
 'terra_proto.ibc.applications.interchain_accounts.host',
 'terra_proto.ibc.applications.interchain_accounts.host.v1',
 'terra_proto.ibc.applications.interchain_accounts.v1',
 'terra_proto.ibc.applications.transfer',
 'terra_proto.ibc.applications.transfer.v1',
 'terra_proto.ibc.applications.transfer.v2',
 'terra_proto.ibc.core',
 'terra_proto.ibc.core.channel',
 'terra_proto.ibc.core.channel.v1',
 'terra_proto.ibc.core.client',
 'terra_proto.ibc.core.client.v1',
 'terra_proto.ibc.core.commitment',
 'terra_proto.ibc.core.commitment.v1',
 'terra_proto.ibc.core.connection',
 'terra_proto.ibc.core.connection.v1',
 'terra_proto.ibc.core.types',
 'terra_proto.ibc.core.types.v1',
 'terra_proto.ibc.lightclients',
 'terra_proto.ibc.lightclients.localhost',
 'terra_proto.ibc.lightclients.localhost.v1',
 'terra_proto.ibc.lightclients.solomachine',
 'terra_proto.ibc.lightclients.solomachine.v1',
 'terra_proto.ibc.lightclients.solomachine.v2',
 'terra_proto.ibc.lightclients.tendermint',
 'terra_proto.ibc.lightclients.tendermint.v1',
 'terra_proto.ics23',
 'terra_proto.tendermint',
 'terra_proto.tendermint.abci',
 'terra_proto.tendermint.crypto',
 'terra_proto.tendermint.libs',
 'terra_proto.tendermint.libs.bits',
 'terra_proto.tendermint.p2p',
 'terra_proto.tendermint.types',
 'terra_proto.tendermint.version',
 'terra_proto.terra',
 'terra_proto.terra.ante',
 'terra_proto.terra.ante.v2']

package_data = \
{'': ['*']}

install_requires = \
['betterproto==2.0.0b4']

setup_kwargs = {
    'name': 'terra-proto',
    'version': '2.0.1b0',
    'description': 'The Python Protobuf implementation for Terra',
    'long_description': '# python implementation for terra.proto\n',
    'author': 'Terraform Labs, PTE.',
    'author_email': 'engineering@terra.money',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/terra-money/terra.proto',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
